==> onesignal_flutter-3.3.1.tar.gz: ios/Classes/OSFlutterCategories.h <==
/**
 * Modified MIT License
 *
 * Copyright 2017 OneSignal
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * 1. The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * 2. All copies of substantial portions of the Software may only be used in connection
 * with services provided by OneSignal.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#import <OneSignal/OneSignal.h>
#import <Flutter/Flutter.h>

#ifndef OneSignalCategories_h
#define OneSignalCategories_h

@interface OSNotification (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSNotificationOpenedResult (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessageAction (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessage (Flutter)
- (NSDictionary *)toJson;
@end

@interface NSError (Flutter)
- (FlutterError *)flutterError;
@end

#endif

==> onesignal_flutter-5.1.2.tar.gz: ios/Classes/OSFlutterCategories.h <==
/**
 * Modified MIT License
 *
 * Copyright 2017 OneSignal
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * 1. The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * 2. All copies of substantial portions of the Software may only be used in connection
 * with services provided by OneSignal.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#import <Flutter/Flutter.h>
#import <OneSignalFramework/OneSignalFramework.h>

#ifndef OneSignalCategories_h
#define OneSignalCategories_h

@interface OSNotification (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSNotificationWillDisplayEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSNotificationClickEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSNotificationClickResult (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessage (Flutter)
- (NSDictionary *)toJson;
@end

@interface NSError (Flutter)
- (FlutterError *)flutterError;
@end

@interface OSInAppMessageWillDisplayEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessageDidDisplayEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessageWillDismissEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessageDidDismissEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessageClickEvent (Flutter)
- (NSDictionary *)toJson;
@end

@interface OSInAppMessageClickResult (Flutter)
- (NSDictionary *)toJson;
@end

#endif
